
/* This file is generated by glib-mkenums, do not modify it. This code is licensed under the same license as the containing project. Note that it links to GLib, so must comply with the LGPL linking clauses. */

#ifndef GP_ENUM_TYPES_H
#define GP_ENUM_TYPES_H

#include <glib-object.h>

G_BEGIN_DECLS
GType gp_applet_flags_get_type (void) G_GNUC_CONST;
#define GP_TYPE_APPLET_FLAGS (gp_applet_flags_get_type())
GType gp_lockdown_flags_get_type (void) G_GNUC_CONST;
#define GP_TYPE_LOCKDOWN_FLAGS (gp_lockdown_flags_get_type())
G_END_DECLS

#endif

/* Generated data ends here */

